# INFO

A tiny docker container to compile teqp to WASM and javascript

To run: ``docker-compose up --build``

The catch tests will run (faster than native!) in node

# Benchmark

Open bench.html from the root directory. Start a simple web server with ``python -m http.server`` so that WASM will serve properly

# Catch tests

Miss the files, but run
